@@ -3,8 +3,6 @@ from importlib.util import module_from_spec, spec_from_file_location
 from typing import Dict, Optional, Callable
 from typing import Set
 
-from parameters_validation import non_blank
-from parameters_validation import non_null
 from pycollect import PythonFileCollector, find_module_name
 
 from injectable.container.injectable import Injectable
@@ -28,7 +26,7 @@ class InjectionContainer:
 
     LOADING_FILEPATH: Optional[str] = None
     LOADED_FILEPATHS: Set[str] = set()
-    CONTEXT: Dict[str, Namespace] = {}
+    NAMESPACES: Dict[str, Namespace] = {}
     DEFAULT_NAMESPACE: str
 
     def __new__(cls):
@@ -36,10 +34,7 @@ class InjectionContainer:
 
     @classmethod
     def load(
-        cls,
-        search_path: non_blank(str) = None,
-        *,
-        default_namespace: non_blank(str) = None,
+        cls, search_path: str = None, *, default_namespace: str = None,
     ):
         """
         Loads injectables under the search path to the :class:`InjectionContainer`
@@ -60,10 +55,11 @@ class InjectionContainer:
         Usage::
 
           >>> from injectable import InjectionContainer
+          >>>
           >>> InjectionContainer.load()
         """
         cls.DEFAULT_NAMESPACE = default_namespace or "_GLOBAL"
-        cls.CONTEXT[default_namespace] = Namespace()
+        cls.NAMESPACES[default_namespace] = Namespace()
         if search_path is None:
             search_path = os.path.dirname(get_caller_filepath())
         elif not os.path.isabs(search_path):
@@ -74,37 +70,41 @@ class InjectionContainer:
     @classmethod
     def _register_injectable(
         cls,
-        klass: non_null(type),
-        qualifier: non_blank(str) = None,
+        klass: type,
+        filepath: str,
+        qualifier: str = None,
         primary: bool = False,
-        namespace: non_blank(str) = None,
-        group: non_blank(str) = None,
+        namespace: str = None,
+        group: str = None,
         singleton: bool = False,
     ):
-        injectable = Injectable(klass, primary, group, singleton)
+        unique_id = f"{klass.__qualname__}@{filepath}"
+        injectable = Injectable(klass, unique_id, primary, group, singleton)
         namespace_entry = cls._get_namespace_entry(namespace or cls.DEFAULT_NAMESPACE)
         namespace_entry.register_injectable(injectable, klass, qualifier)
 
     @classmethod
     def _register_factory(
         cls,
-        factory: non_null(Callable),
-        dependency: non_null(type),
-        qualifier: non_blank(str) = None,
+        factory: Callable,
+        filepath: str,
+        dependency: Optional[type],
+        qualifier: str = None,
         primary: bool = False,
-        namespace: non_blank(str) = None,
-        group: non_blank(str) = None,
+        namespace: str = None,
+        group: str = None,
         singleton: bool = False,
     ):
-        injectable = Injectable(factory, primary, group, singleton)
+        unique_id = f"{factory.__qualname__}@{filepath}"
+        injectable = Injectable(factory, unique_id, primary, group, singleton)
         namespace_entry = cls._get_namespace_entry(namespace or cls.DEFAULT_NAMESPACE)
         namespace_entry.register_injectable(injectable, dependency, qualifier)
 
     @classmethod
     def _get_namespace_entry(cls, namespace: str) -> Namespace:
-        if namespace not in cls.CONTEXT:
-            cls.CONTEXT[namespace] = Namespace()
-        return cls.CONTEXT[namespace]
+        if namespace not in cls.NAMESPACES:
+            cls.NAMESPACES[namespace] = Namespace()
+        return cls.NAMESPACES[namespace]
 
     @classmethod
     def _link_dependencies(cls, search_path: str):
