@@ -1,6 +1,6 @@
 import inspect
 import os
-from typing import AnyStr
+from typing import AnyStr, Union
 
 
 def get_caller_filepath(steps_back: int = 2) -> AnyStr:
@@ -15,3 +15,9 @@ def get_caller_filepath(steps_back: int = 2) -> AnyStr:
     filepath = frame_info.filename
     del frame_info
     return os.path.abspath(filepath)
+
+
+def get_dependency_name(dependency: Union[type, callable, str]) -> str:
+    if isinstance(dependency, str):
+        return dependency
+    return dependency.__qualname__
